@@ -9,6 +9,7 @@ keys = [
     'password',
     'account_id',
     'budget_id',
+    'mfa_seed_token',
 ]
 
 
@@ -16,11 +17,10 @@ def _updateSecrets():
     # degenerate function on purpose. the filesystem is weird,
     # but it usually works out in the end, so we fail open.
     try:
-        with open(secretsPath, 'r+') as file:
+        with open(secretsPath, 'r') as file:
             return json.load(file)
     except:
-        newfile()
-        return _updateSecrets()
+        return {}
 
 
 def update(key, value):
@@ -31,7 +31,7 @@ def update(key, value):
     secrets = _updateSecrets()
     # don't overwrite non-blank value with blank value
     # if no value at all, add blank value.
-    if value != '' or not secrets[key]:
+    if value != '' or key not in secrets:
         secrets[key] = value
         with open(secretsPath, 'w+') as file:
             file.write(json.dumps(secrets, indent=2))
